class ClientUrls:
    LOGIN_URL='https://www.instagram.com/accounts/login/'
    NAV_USER='https://www.instagram.com/{}/'
    SEARCH_TAGS='https://www.instagram.com/explore/tags/{}/'
    FOLLOWERS_URL = 'https://www.instagram.com/{}/followers/'
    HOME_URL =  'https://instagram.com/'